## [0.1.11] - 2025-05-13

- added support for limiting number of returned documents with `K` parameter
- added new PlainID exceptions, which you can use for checking what module caused the error during piping through the chain. Also it contains exact PlainID error message.
